# mimicap prebuild

https://github.com/bbsvip/minicap_minitouch_prebuilt/tree/main

- android-32:

https://github.com/UrielCh/minicap-prebuilt


# mimitouch prebuild

https://github.com/bbsvip/minicap_minitouch_prebuilt/tree/main


# ADBKeyboard prebuild

https://github.com/senzhk/ADBKeyBoard

